﻿using System;
using System.Linq;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Runtime.CompilerServices;
using Windows.ApplicationModel.Resources.Core;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Media.Imaging;
using System.Collections.Specialized;
using Windows.UI.Xaml;

// The data model defined by this file serves as a representative example of a strongly-typed
// model that supports notification when members are added, removed, or modified.  The property
// names chosen coincide with data bindings in the standard item templates.
//
// Applications may use this model as a starting point and build on it, or discard it entirely and
// replace it with something appropriate to their needs.

namespace Finance.Data
{
    /// <summary>
    /// Base class for <see cref="SampleDataItem"/> and <see cref="SampleDataGroup"/> that
    /// defines properties common to both.
    /// </summary>
    [Windows.Foundation.Metadata.WebHostHidden]
    public abstract class SampleDataCommon : Finance.Common.BindableBase
    {
        private static Uri _baseUri = new Uri("ms-appx:///");

        public SampleDataCommon(String uniqueId, String title, String subtitle, String imagePath, String description)
        {
            this._uniqueId = uniqueId;
            this._title = title;
            this._subtitle = subtitle;
            this._description = description;
            this._imagePath = imagePath;
        }

        private string _uniqueId = string.Empty;
        public string UniqueId
        {
            get { return this._uniqueId; }
            set { this.SetProperty(ref this._uniqueId, value); }
        }

        private string _title = string.Empty;
        public string Title
        {
            get { return this._title; }
            set { this.SetProperty(ref this._title, value); }
        }

        private string _subtitle = string.Empty;
        public string Subtitle
        {
            get { return this._subtitle; }
            set { this.SetProperty(ref this._subtitle, value); }
        }

        private string _Level1 = string.Empty;
        public string Level1
        {
            get { return this._Level1; }
            set { this.SetProperty(ref this._Level1, value); }
        }

        private string _Level2 = string.Empty;
        public string Level2
        {
            get { return this._Level2; }
            set { this.SetProperty(ref this._Level2, value); }
        }
        private Visibility _Low = Visibility.Collapsed;
        public Visibility Low
        {
            get { return this._Low; }
            set { this.SetProperty(ref this._Low, value); }
        }

        private Visibility _High = Visibility.Collapsed;
        public Visibility High
        {
            get { return this._High; }
            set { this.SetProperty(ref this._High, value); }
        }

        

        private string _description = string.Empty;
        public string Description
        {
            get { return this._description; }
            set { this.SetProperty(ref this._description, value); }
        }

        private ImageSource _image = null;
        private String _imagePath = null;
        public ImageSource Image
        {
            get
            {
                if (this._image == null && this._imagePath != null)
                {
                    this._image = new BitmapImage(new Uri(SampleDataCommon._baseUri, this._imagePath));
                }
                return this._image;
            }

            set
            {
                this._imagePath = null;
                this.SetProperty(ref this._image, value);
            }
        }

        public void SetImage(String path)
        {
            this._image = null;
            this._imagePath = path;
            this.OnPropertyChanged("Image");
        }

        public override string ToString()
        {
            return this.Title;
        }
    }

    /// <summary>
    /// Generic item data model.
    /// </summary>
    public class SampleDataItem : SampleDataCommon
    {
        public SampleDataItem(String uniqueId, String title, String subtitle, String imagePath, String description, String content, int colSpan, int rowSpan, SampleDataGroup group)
            : base(uniqueId, title, subtitle, imagePath, description)
        {
            this._colSpan = colSpan;
            this._rowSpan = rowSpan;
            this._content = content;
            this._group = group;
        }

        private string _content = string.Empty;
        public string Content
        {
            get { return this._content; }
            set { this.SetProperty(ref this._content, value); }
        }

        private int _rowSpan = 1;
        public int RowSpan
        {
            get { return this._rowSpan; }
            set { this.SetProperty(ref this._rowSpan, value); }
        }

        private int _colSpan = 1;
        public int ColSpan
        {
            get { return this._colSpan; }
            set { this.SetProperty(ref this._colSpan, value); }
        }


        private SampleDataGroup _group;
        public SampleDataGroup Group
        {
            get { return this._group; }
            set { this.SetProperty(ref this._group, value); }
        }
    }

    /// <summary>
    /// Generic group data model.
    /// </summary>
    public class SampleDataGroup : SampleDataCommon
    {
        public SampleDataGroup(String uniqueId, String title, String subtitle, String imagePath, String description)
            : base(uniqueId, title, subtitle, imagePath, description)
        {
            Items.CollectionChanged += ItemsCollectionChanged;
        }

        private void ItemsCollectionChanged(object sender, System.Collections.Specialized.NotifyCollectionChangedEventArgs e)
        {
            // Provides a subset of the full items collection to bind to from a GroupedItemsPage
            // for two reasons: GridView will not virtualize large items collections, and it
            // improves the user experience when browsing through groups with large numbers of
            // items.
            //
            // A maximum of 12 items are displayed because it results in filled grid columns
            // whether there are 1, 2, 3, 4, or 6 rows displayed

            switch (e.Action)
            {
                case NotifyCollectionChangedAction.Add:
                    if (e.NewStartingIndex < 12)
                    {
                        TopItems.Insert(e.NewStartingIndex, Items[e.NewStartingIndex]);
                        if (TopItems.Count > 12)
                        {
                            TopItems.RemoveAt(12);
                        }
                    }
                    break;
                case NotifyCollectionChangedAction.Move:
                    if (e.OldStartingIndex < 12 && e.NewStartingIndex < 12)
                    {
                        TopItems.Move(e.OldStartingIndex, e.NewStartingIndex);
                    }
                    else if (e.OldStartingIndex < 12)
                    {
                        TopItems.RemoveAt(e.OldStartingIndex);
                        TopItems.Add(Items[11]);
                    }
                    else if (e.NewStartingIndex < 12)
                    {
                        TopItems.Insert(e.NewStartingIndex, Items[e.NewStartingIndex]);
                        TopItems.RemoveAt(12);
                    }
                    break;
                case NotifyCollectionChangedAction.Remove:
                    if (e.OldStartingIndex < 12)
                    {
                        TopItems.RemoveAt(e.OldStartingIndex);
                        if (Items.Count >= 12)
                        {
                            TopItems.Add(Items[11]);
                        }
                    }
                    break;
                case NotifyCollectionChangedAction.Replace:
                    if (e.OldStartingIndex < 12)
                    {
                        TopItems[e.OldStartingIndex] = Items[e.OldStartingIndex];
                    }
                    break;
                case NotifyCollectionChangedAction.Reset:
                    TopItems.Clear();
                    while (TopItems.Count < Items.Count && TopItems.Count < 12)
                    {
                        TopItems.Add(Items[TopItems.Count]);
                    }
                    break;
            }
        }

        private ObservableCollection<SampleDataItem> _items = new ObservableCollection<SampleDataItem>();
        public ObservableCollection<SampleDataItem> Items
        {
            get { return this._items; }
        }

        private ObservableCollection<SampleDataItem> _topItem = new ObservableCollection<SampleDataItem>();
        public ObservableCollection<SampleDataItem> TopItems
        {
            get { return this._topItem; }
        }

       




    }

    /// <summary>
    /// Creates a collection of groups and items with hard-coded content.
    /// 
    /// SampleDataSource initializes with placeholder data rather than live production
    /// data so that sample data is provided at both design-time and run-time.
    /// </summary>
    public sealed class SampleDataSource
    {
        private static SampleDataSource _sampleDataSource = new SampleDataSource();

        private ObservableCollection<SampleDataGroup> _allGroups = new ObservableCollection<SampleDataGroup>();
        public ObservableCollection<SampleDataGroup> AllGroups
        {
            get { return this._allGroups; }
        }

        public static IEnumerable<SampleDataGroup> GetGroups(string uniqueId)
        {
            if (!uniqueId.Equals("AllGroups")) throw new ArgumentException("Only 'AllGroups' is supported as a collection of groups");

            return _sampleDataSource.AllGroups;
        }

        public static SampleDataGroup GetGroup(string uniqueId)
        {
            // Simple linear search is acceptable for small data sets
            var matches = _sampleDataSource.AllGroups.Where((group) => group.UniqueId.Equals(uniqueId));
            if (matches.Count() == 1) return matches.First();
            return null;
        }

        public static SampleDataItem GetItem(string uniqueId)
        {
            // Simple linear search is acceptable for small data sets
            var matches = _sampleDataSource.AllGroups.SelectMany(group => group.Items).Where((item) => item.UniqueId.Equals(uniqueId));
            if (matches.Count() == 1) return matches.First();
            return null;
        }



        public SampleDataSource()
        {
            String ITEM_CONTENT = String.Format("Item Content: {0}\n\n{0}\n\n{0}\n\n{0}\n\n{0}\n\n{0}\n\n{0}",
                        "Curabitur class aliquam vestibulum nam curae maecenas sed integer cras phasellus suspendisse quisque donec dis praesent accumsan bibendum pellentesque condimentum adipiscing etiam consequat vivamus dictumst aliquam duis convallis scelerisque est parturient ullamcorper aliquet fusce suspendisse nunc hac eleifend amet blandit facilisi condimentum commodo scelerisque faucibus aenean ullamcorper ante mauris dignissim consectetuer nullam lorem vestibulum habitant conubia elementum pellentesque morbi facilisis arcu sollicitudin diam cubilia aptent vestibulum auctor eget dapibus pellentesque inceptos leo egestas interdum nulla consectetuer suspendisse adipiscing pellentesque proin lobortis sollicitudin augue elit mus congue fermentum parturient fringilla euismod feugiat");

            var group1 = new SampleDataGroup("Group-1",
                 "Market Watch",
                 "Group Subtitle: 1",
                 "Assets/DarkGray.png",
                 "Group Description: Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus tempor scelerisque lorem in vehicula. Aliquam tincidunt, lacus ut sagittis tristique, turpis massa volutpat augue, eu rutrum ligula ante a ante");

            group1.Items.Add(new SampleDataItem("NormalTile-Group-1-Item1",
                 "Lorem ipsum",
                 "2278.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group1) {Level1="+11.52", Level2="+0.50%", High=Visibility.Visible });

            group1.Items.Add(new SampleDataItem("NormalTile-Group-1-Item2",
                "Lorem ipsum",
                 "3245.78",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group1) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group1.Items.Add(new SampleDataItem("NormalTile-Group-1-Item3",
               "Lorem ipsum",
                "11990.5",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                47,
                16,
                group1) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group1.Items.Add(new SampleDataItem("NormalTile-Group-1-Item4",
               "Lorem ipsum",
                "3245.78",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                47,
                16,
                group1) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group1.Items.Add(new SampleDataItem("NormalTile-Group-1-Item5",
               "Lorem ipsum",
                "11990.5",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                47,
                16,
                group1) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group1.Items.Add(new SampleDataItem("NormalTile-Group-1-Item6",
               "Lorem ipsum",
                "3245.78",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                47,
                16,
                group1) { Level1 = "+11.52", Level2 = "+0.50%", Low = Visibility.Visible });
            group1.Items.Add(new SampleDataItem("NormalTile-Group-1-Item7",
               "Lorem ipsum",
                "11990.5",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                47,
                16,
                group1) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group1.Items.Add(new SampleDataItem("NormalTile-Group-1-Item8",
               "Lorem ipsum",
                "3245.78",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                47,
                16,
                group1) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group1.Items.Add(new SampleDataItem("NormalTile-Group-1-Item9",
               "Lorem ipsum",
                "11990.5",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                47,
                16,
                group1) { Level1 = "+11.52", Level2 = "+0.50%", Low = Visibility.Visible });
            group1.Items.Add(new SampleDataItem("NormalTile-Group-1-Item10",
               "Lorem ipsum",
                "3245.78",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                47,
                16,
                group1) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group1.Items.Add(new SampleDataItem("NormalTile-Group-1-Item11",
               "Lorem ipsum",
                "11990.5",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                47,
                16,
                group1) { Level1 = "+11.52", Level2 = "+0.50%", Low = Visibility.Visible });
            group1.Items.Add(new SampleDataItem("NormalTile-Group-1-Item12",
               "Lorem ipsum",
                "3245.78",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                47,
                16,
                group1) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group1.Items.Add(new SampleDataItem("NormalTile-Group-1-Item13",
               "Lorem ipsum",
                "11990.5",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                47,
                16,
                group1) { Level1 = "+11.52", Level2 = "+0.50%", Low = Visibility.Visible });
            group1.Items.Add(new SampleDataItem("NormalTile-Group-1-Item14",
               "Lorem ipsum",
                "3245.78",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                47,
                16,
                group1) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group1.Items.Add(new SampleDataItem("NormalTile-Group-1-Item15",
               "Lorem ipsum",
                "11990.5",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                47,
                16,
                group1) { Level1 = "+11.52", Level2 = "+0.50%", Low = Visibility.Visible });
            group1.Items.Add(new SampleDataItem("NormalTile-Group-1-Item16",
               "Lorem ipsum",
                "3245.78",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                47,
                16,
                group1) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group1.Items.Add(new SampleDataItem("NormalTile-Group-1-Item17",
               "Lorem ipsum",
                "11990.5",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                47,
                16,
                group1) { Level1 = "+11.52", Level2 = "+0.50%", Low = Visibility.Visible });
            group1.Items.Add(new SampleDataItem("NormalTile-Group-1-Item18",
               "Lorem ipsum",
                "2278.59",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                47,
                16,
                group1) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });

            this.AllGroups.Add(group1);

            var group2 = new SampleDataGroup("Group-2",
                 "World Indices",
                 "Group Subtitle: 1",
                 "Assets/DarkGray.png",
                 "Group Description: Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus tempor scelerisque lorem in vehicula. Aliquam tincidunt, lacus ut sagittis tristique, turpis massa volutpat augue, eu rutrum ligula ante a ante");

            group2.Items.Add(new SampleDataItem("NormalTile-Group-2-Item1",
                 "Lorem ipsum",
                 "2278.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group2) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });

            group2.Items.Add(new SampleDataItem("NormalTile-Group-2-Item2",
                 "Lorem ipsum",
                 "11990.5",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group2) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });

            group2.Items.Add(new SampleDataItem("NormalTile-Group-2-Item3",
                 "Lorem ipsum",
                 "3245.78",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group2) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            this.AllGroups.Add(group2);

            var group3 = new SampleDataGroup("Group-3",
                "World Indices",
                "Group Subtitle: 1",
                "Assets/DarkGray.png",
                "Group Description: Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus tempor scelerisque lorem in vehicula. Aliquam tincidunt, lacus ut sagittis tristique, turpis massa volutpat augue, eu rutrum ligula ante a ante");

            group3.Items.Add(new SampleDataItem("News-Group-3-Item1",
                 "Lorem ipsum",
                 "Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 74,
                 22,
                 group3));
            group3.Items.Add(new SampleDataItem("News-Group-3-Item2",
                "Lorem ipsum",
                "Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                74,
                22,
                group3));
            group3.Items.Add(new SampleDataItem("News-Group-3-Item3",
                "Lorem ipsum",
                "Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                74,
                22,
                group3));
            group3.Items.Add(new SampleDataItem("News-Group-3-Item4",
               "Lorem ipsum",
               "Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type",
               "Assets/HubPage/HubpageImage1.png",
               "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
               ITEM_CONTENT,
               74,
               22,
               group3));
            this.AllGroups.Add(group3);

            var group4 = new SampleDataGroup("Group-4",
                "Gainers",
                "Group Subtitle: 1",
                "Assets/DarkGray.png",
                "Group Description: Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus tempor scelerisque lorem in vehicula. Aliquam tincidunt, lacus ut sagittis tristique, turpis massa volutpat augue, eu rutrum ligula ante a ante");

            group4.Items.Add(new SampleDataItem("NormalTile-Group-4-Item1",
                 "Lorem ipsum",
                 "2278.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group4) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group4.Items.Add(new SampleDataItem("NormalTile-Group-4-Item2",
                "Lorem ipsum",
                "2278.59",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                47,
                16,
                group4) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group4.Items.Add(new SampleDataItem("NormalTile-Group-4-Item3",
                "Lorem ipsum",
                "2278.59",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                47,
                16,
                group4) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group4.Items.Add(new SampleDataItem("NormalTile-Group-4-Item4",
                "Lorem ipsum",
                "4278.59",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                47,
                16,
                group4) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group4.Items.Add(new SampleDataItem("NormalTile-Group-4-Item5",
                "Lorem ipsum",
                "1278.59",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                47,
                16,
                group4) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group4.Items.Add(new SampleDataItem("NormalTile-Group-4-Item6",
                "Lorem ipsum",
                "3278.59",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                47,
                16,
                group4) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            this.AllGroups.Add(group4);

            var group5 = new SampleDataGroup("Group-5",
               "Losers",
               "Group Subtitle: 1",
               "Assets/DarkGray.png",
               "Group Description: Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus tempor scelerisque lorem in vehicula. Aliquam tincidunt, lacus ut sagittis tristique, turpis massa volutpat augue, eu rutrum ligula ante a ante");

            group5.Items.Add(new SampleDataItem("NormalTile-Group-5-Item1",
                 "Lorem ipsum",
                 "2278.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group5) { Level1 = "+11.52", Level2 = "+0.50%", Low = Visibility.Visible });
            group5.Items.Add(new SampleDataItem("NormalTile-Group-5-Item2",
                "Lorem ipsum",
                "3278.59",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                47,
                16,
                group5) { Level1 = "+11.52", Level2 = "+0.50%", Low = Visibility.Visible });
            group5.Items.Add(new SampleDataItem("NormalTile-Group-5-Item3",
                "Lorem ipsum",
                "2278.59",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                47,
                16,
                group5) { Level1 = "+11.52", Level2 = "+0.50%", Low = Visibility.Visible });
            group5.Items.Add(new SampleDataItem("NormalTile-Group-5-Item4",
                "Lorem ipsum",
                "3278.59",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                47,
                16,
                group5) { Level1 = "+11.52", Level2 = "+0.50%", Low = Visibility.Visible });
            group5.Items.Add(new SampleDataItem("NormalTile-Group-5-Item5",
                "Lorem ipsum",
                "1278.59",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                47,
                16,
                group5) { Level1 = "+11.52", Level2 = "+0.50%", Low = Visibility.Visible });
            group5.Items.Add(new SampleDataItem("NormalTile-Group-5-Item6",
                "Lorem ipsum",
                "2278.59",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                47,
                16,
                group5) { Level1 = "+11.52", Level2 = "+0.50%", Low = Visibility.Visible });
            this.AllGroups.Add(group5);

            var group6 = new SampleDataGroup("Group-6",
               "Most Active Scrips",
               "Group Subtitle: 1",
               "Assets/DarkGray.png",
               "Group Description: Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus tempor scelerisque lorem in vehicula. Aliquam tincidunt, lacus ut sagittis tristique, turpis massa volutpat augue, eu rutrum ligula ante a ante");

            group6.Items.Add(new SampleDataItem("NormalTile-Group-6-Item1",
                 "Lorem ipsum",
                 "2278.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group6) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group6.Items.Add(new SampleDataItem("NormalTile-Group-6-Item2",
                 "Lorem ipsum",
                 "4278.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group6) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group6.Items.Add(new SampleDataItem("NormalTile-Group-6-Item3",
                 "Lorem ipsum",
                 "3278.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group6) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group6.Items.Add(new SampleDataItem("NormalTile-Group-6-Item4",
                 "Lorem ipsum",
                 "1278.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group6) { Level1 = "+11.52", Level2 = "+0.50%", Low = Visibility.Visible });
            group6.Items.Add(new SampleDataItem("NormalTile-Group-6-Item5",
                 "Lorem ipsum",
                 "2278.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group6) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group6.Items.Add(new SampleDataItem("NormalTile-Group-6-Item6",
                 "Lorem ipsum",
                 "1278.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group6) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group6.Items.Add(new SampleDataItem("NormalTile-Group-6-Item7",
                 "Lorem ipsum",
                 "5278.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group6) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group6.Items.Add(new SampleDataItem("NormalTile-Group-6-Item8",
                 "Lorem ipsum",
                 "4278.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group6) { Level1 = "+11.52", Level2 = "+0.50%", Low = Visibility.Visible });
            group6.Items.Add(new SampleDataItem("NormalTile-Group-6-Item9",
                 "Lorem ipsum",
                 "578.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group6) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group6.Items.Add(new SampleDataItem("NormalTile-Group-6-Item10",
                 "Lorem ipsum",
                 "3278.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group6) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group6.Items.Add(new SampleDataItem("NormalTile-Group-6-Item11",
                 "Lorem ipsum",
                 "2178.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group6) { Level1 = "+11.52", Level2 = "+0.50%", Low = Visibility.Visible });
            group6.Items.Add(new SampleDataItem("NormalTile-Group-6-Item12",
                 "Lorem ipsum",
                 "3278.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group6) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            this.AllGroups.Add(group6);

            var group7 = new SampleDataGroup("Group-7",
               "Reports",
               "Group Subtitle: 1",
               "Assets/DarkGray.png",
               "Group Description: Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus tempor scelerisque lorem in vehicula. Aliquam tincidunt, lacus ut sagittis tristique, turpis massa volutpat augue, eu rutrum ligula ante a ante");

            group7.Items.Add(new SampleDataItem("News-Group-7-Item1",
                 "Lorem ipsum",
                 "Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 74,
                 22,
                 group7));
            group7.Items.Add(new SampleDataItem("News-Group-7-Item2",
                "Lorem ipsum",
                "Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                74,
                22,
                group7));
            group7.Items.Add(new SampleDataItem("News-Group-7-Item3",
                "Lorem ipsum",
                "Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type",
                "Assets/HubPage/HubpageImage1.png",
                "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                ITEM_CONTENT,
                74,
                22,
                group7));
           
            this.AllGroups.Add(group7);

            var group8 = new SampleDataGroup("Group-8",
               "My Scrips",
               "Group Subtitle: 1",
               "Assets/DarkGray.png",
               "Group Description: Lorem ipsum dolor sit amet, consectetur adipiscing elit. Vivamus tempor scelerisque lorem in vehicula. Aliquam tincidunt, lacus ut sagittis tristique, turpis massa volutpat augue, eu rutrum ligula ante a ante");

            group8.Items.Add(new SampleDataItem("NormalTile-Group-8-Item1",
                 "Lorem ipsum",
                 "2278.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group8) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group8.Items.Add(new SampleDataItem("NormalTile-Group-8-Item2",
                 "Lorem ipsum",
                 "4278.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group8) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group8.Items.Add(new SampleDataItem("NormalTile-Group-8-Item3",
                 "Lorem ipsum",
                 "3278.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group8) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group8.Items.Add(new SampleDataItem("NormalTile-Group-8-Item4",
                 "Lorem ipsum",
                 "1278.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group8) { Level1 = "+11.52", Level2 = "+0.50%", Low = Visibility.Visible });
            group8.Items.Add(new SampleDataItem("NormalTile-Group-8-Item5",
                 "Lorem ipsum",
                 "2278.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group8) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group8.Items.Add(new SampleDataItem("NormalTile-Group-8-Item6",
                 "Lorem ipsum",
                 "1278.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group8) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group8.Items.Add(new SampleDataItem("NormalTile-Group-8-Item7",
                 "Lorem ipsum",
                 "5278.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group8) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group8.Items.Add(new SampleDataItem("NormalTile-Group-8-Item8",
                 "Lorem ipsum",
                 "4278.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group8) { Level1 = "+11.52", Level2 = "+0.50%", Low = Visibility.Visible });
            group8.Items.Add(new SampleDataItem("NormalTile-Group-8-Item9",
                 "Lorem ipsum",
                 "578.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group8) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group8.Items.Add(new SampleDataItem("NormalTile-Group-8-Item10",
                 "Lorem ipsum",
                 "3278.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group8) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            group8.Items.Add(new SampleDataItem("NormalTile-Group-8-Item11",
                 "Lorem ipsum",
                 "2178.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group8) { Level1 = "+11.52", Level2 = "+0.50%", Low = Visibility.Visible });
            group8.Items.Add(new SampleDataItem("NormalTile-Group-8-Item12",
                 "Lorem ipsum",
                 "3278.59",
                 "Assets/HubPage/HubpageImage1.png",
                 "Item Description: Pellentesque porta, mauris quis interdum vehicula, urna sapien ultrices velit, nec venenatis dui odio in augue. Cras posuere, enim a cursus convallis, neque turpis malesuada erat, ut adipiscing neque tortor ac erat.",
                 ITEM_CONTENT,
                 47,
                 16,
                 group8) { Level1 = "+11.52", Level2 = "+0.50%", High = Visibility.Visible });
            this.AllGroups.Add(group8);




        }
    }
}
